@@ -32,13 +32,18 @@
 
 """|UDM| module for printer shares"""
 
+from typing import TYPE_CHECKING
+
 import univention.admin.filter
 import univention.admin.handlers
-import univention.admin.handlers.shares.printer
-import univention.admin.handlers.shares.printergroup
 import univention.admin.localization
 
 
+if TYPE_CHECKING:
+    import univention.admin
+    import univention.admin.uldap
+
+
 translation = univention.admin.localization.translation('univention.admin.handlers.shares')
 _ = translation.translate
 
@@ -51,7 +56,7 @@ object_name_plural = _('Printer shares')
 long_description = ''
 operations = ['search']
 virtual = True
-options = {}
+options = {}  # type: dict[str, univention.admin.option]
 property_descriptions = {
     'name': univention.admin.property(
         short_description=_('Name'),
@@ -86,11 +91,14 @@ class object(univention.admin.handlers.simpleLdap):
 
 
 def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=False, required=False, timeout=-1, sizelimit=0):
-    res = []
-    for module in (univention.admin.handlers.shares.printer, univention.admin.handlers.shares.printergroup):
-        res.extend(module.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit))
+    # type: (None, univention.admin.uldap.access,str, str, univention.admin.handlers.simpleLdap | None, str, bool, bool, int, int) -> list[univention.admin.handlers.simpleLdap]
+    res = []  # type: list[univention.admin.handlers.simpleLdap]
+    for child in childmodules:
+        mod = univention.admin.modules._get(child)
+        res += mod.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
     return res
 
 
 def identify(dn, attr, canonical=False):
+    # type: (str, univention.admin.handlers._Attributes, bool) -> None
     pass
